@@ -17,6 +17,10 @@ def parse():
         '--dry-run',
         action='store_true',
         help='Run without making any changes to your DynamoDB table')
+    parser.add_argument(
+        '--run-once',
+        action='store_true',
+        help='Run once and then exit Dynamic DynamoDB, instead of looping')
     parser.add_argument(
         '--check-interval',
         type=int,
@@ -115,6 +119,16 @@ def parse():
         '--max-provisioned-reads',
         type=int,
         help="""Maximum number of provisioned reads""")
+    r_scaling_ag.add_argument(
+        '--num-read-checks-before-scale-down',
+        type=int,
+        help="""Number of consecutive checks that must meet criteria
+            before a scale down event occurs""")
+    r_scaling_ag.add_argument(
+        '--num-read-checks-reset-percent',
+        type=int,
+        help="""Percentage Value that will cause the num_read_checks_before
+            scale_down var to reset back to 0""")
     w_scaling_ag = parser.add_argument_group('Write units scaling properties')
     w_scaling_ag.add_argument(
         '--writes-upper-threshold',
@@ -144,11 +158,11 @@ def parse():
         type=int,
         help="""How many percent should we decrease the write
                 units with? (default: 50)""")
-    r_scaling_ag.add_argument(
+    w_scaling_ag.add_argument(
         '--increase-writes-unit',
         type=str,
         help='Do you want to scale in percent or units? (default: percent)')
-    r_scaling_ag.add_argument(
+    w_scaling_ag.add_argument(
         '--decrease-writes-unit',
         type=str,
         help='Do you want to scale in percent or units? (default: percent)')
@@ -160,6 +174,16 @@ def parse():
         '--max-provisioned-writes',
         type=int,
         help="""Maximum number of provisioned writes""")
+    w_scaling_ag.add_argument(
+        '--num-write-checks-before-scale-down',
+        type=int,
+        help="""Number of consecutive checks that must meet criteria
+            before a scale down event occurs""")
+    w_scaling_ag.add_argument(
+        '--num-write-checks-reset-percent',
+        type=int,
+        help="""Percentage Value that will cause the num_write_checks_before
+            scale_down var to reset back to 0""")
     args = parser.parse_args()
 
     # Print the version and quit
