@@ -324,6 +324,30 @@ def parse(config_path):
                     'option': 'sns-message-types',
                     'required': False,
                     'type': 'str'
+                },
+                {
+                    'key': 'num_read_checks_before_scale_down',
+                    'option': 'num-read-checks-before-scale-down',
+                    'required': False,
+                    'type': 'int'
+                },
+                {
+                    'key': 'num_write_checks_before_scale_down',
+                    'option': 'num-write-checks-before-scale-down',
+                    'required': False,
+                    'type': 'int'
+                },
+                {
+                    'key': 'num_write_checks_reset_percent',
+                    'option': 'num-write-checks-reset-percent',
+                    'required': False,
+                    'type': 'int'
+                },
+                {
+                    'key': 'num_read_checks_reset_percent',
+                    'option': 'num-read-checks-reset-percent',
+                    'required': False,
+                    'type': 'int'
                 }
             ])
 
@@ -510,6 +534,30 @@ def parse(config_path):
                         'option': 'sns-message-types',
                         'required': False,
                         'type': 'str'
+                    },
+                    {
+                        'key': 'num_read_checks_before_scale_down',
+                        'option': 'num-read-checks-before-scale-down',
+                        'required': False,
+                        'type': 'int'
+                    },
+                    {
+                        'key': 'num_write_checks_before_scale_down',
+                        'option': 'num-write-checks-before-scale-down',
+                        'required': False,
+                        'type': 'int'
+                    },
+                    {
+                        'key': 'num_write_checks_reset_percent',
+                        'option': 'num-write-checks-reset-percent',
+                        'required': False,
+                        'type': 'int'
+                    },
+                    {
+                        'key': 'num_read_checks_reset_percent',
+                        'option': 'num-read-checks-reset-percent',
+                        'required': False,
+                        'type': 'int'
                     }
                 ])
 
