@@ -1,10 +1,14 @@
+# -*- coding: utf-8 -*-
 """ This module returns stats about the DynamoDB table """
 import math
 from datetime import datetime, timedelta
 
-from dynamic_dynamodb.core import dynamodb
+from boto.exception import JSONResponseError, BotoServerError
+from retrying import retry
+
+from dynamic_dynamodb.aws import dynamodb
 from dynamic_dynamodb.log_handler import LOGGER as logger
-from dynamic_dynamodb.core.cloudwatch import (
+from dynamic_dynamodb.aws.cloudwatch import (
     CLOUDWATCH_CONNECTION as cloudwatch_connection)
 
 
@@ -19,8 +23,11 @@ def get_consumed_read_units_percent(table_name, gsi_name, time_frame=300):
     :param time_frame: How many seconds to look at
     :returns: int -- Number of consumed reads
     """
-    metrics = __get_aws_metric(
-        table_name, gsi_name, time_frame,  'ConsumedReadCapacityUnits')
+    try:
+        metrics = __get_aws_metric(
+            table_name, gsi_name, time_frame, 'ConsumedReadCapacityUnits')
+    except BotoServerError:
+        raise
 
     if metrics:
         consumed_read_units = int(
@@ -28,11 +35,14 @@ def get_consumed_read_units_percent(table_name, gsi_name, time_frame=300):
     else:
         consumed_read_units = 0
 
-    consumed_read_units_percent = int(
-        math.ceil(
-            float(consumed_read_units) /
-            float(dynamodb.get_provisioned_gsi_read_units(
-                table_name, gsi_name)) * 100))
+    try:
+        consumed_read_units_percent = int(
+            math.ceil(
+                float(consumed_read_units) /
+                float(dynamodb.get_provisioned_gsi_read_units(
+                    table_name, gsi_name)) * 100))
+    except JSONResponseError:
+        raise
 
     logger.info('{0} - GSI: {1} - Consumed read units: {2:d}%'.format(
         table_name, gsi_name, consumed_read_units_percent))
@@ -50,8 +60,11 @@ def get_throttled_read_event_count(table_name, gsi_name, time_frame=300):
     :param time_frame: How many seconds to look at
     :returns: int -- Number of throttled read events
     """
-    metrics = __get_aws_metric(
-        table_name, gsi_name, time_frame, 'ReadThrottleEvents')
+    try:
+        metrics = __get_aws_metric(
+            table_name, gsi_name, time_frame, 'ReadThrottleEvents')
+    except BotoServerError:
+        raise
 
     if metrics:
         throttled_read_events = int(metrics[0]['Sum'])
@@ -74,8 +87,11 @@ def get_consumed_write_units_percent(table_name, gsi_name, time_frame=300):
     :param time_frame: How many seconds to look at
     :returns: int -- Number of consumed writes
     """
-    metrics = __get_aws_metric(
-        table_name, gsi_name, time_frame, 'ConsumedWriteCapacityUnits')
+    try:
+        metrics = __get_aws_metric(
+            table_name, gsi_name, time_frame, 'ConsumedWriteCapacityUnits')
+    except BotoServerError:
+        raise
 
     if metrics:
         consumed_write_units = int(
@@ -83,11 +99,14 @@ def get_consumed_write_units_percent(table_name, gsi_name, time_frame=300):
     else:
         consumed_write_units = 0
 
-    consumed_write_units_percent = int(
-        math.ceil(
-            float(consumed_write_units) /
-            float(dynamodb.get_provisioned_gsi_write_units(
-                table_name, gsi_name)) * 100))
+    try:
+        consumed_write_units_percent = int(
+            math.ceil(
+                float(consumed_write_units) /
+                float(dynamodb.get_provisioned_gsi_write_units(
+                    table_name, gsi_name)) * 100))
+    except JSONResponseError:
+        raise
 
     logger.info('{0} - GSI: {1} - Consumed write units: {2:d}%'.format(
         table_name, gsi_name, consumed_write_units_percent))
@@ -105,8 +124,11 @@ def get_throttled_write_event_count(table_name, gsi_name, time_frame=300):
     :param time_frame: How many seconds to look at
     :returns: int -- Number of throttled write events
     """
-    metrics = __get_aws_metric(
-        table_name, gsi_name, time_frame, 'WriteThrottleEvents')
+    try:
+        metrics = __get_aws_metric(
+            table_name, gsi_name, time_frame, 'WriteThrottleEvents')
+    except BotoServerError:
+        raise
 
     if metrics:
         throttled_write_events = int(metrics[0]['Sum'])
@@ -118,6 +140,10 @@ def get_throttled_write_event_count(table_name, gsi_name, time_frame=300):
     return throttled_write_events
 
 
+@retry(
+    wait='exponential_sleep',
+    wait_exponential_multiplier=1000,
+    wait_exponential_max=5000)
 def __get_aws_metric(table_name, gsi_name, time_frame, metric_name):
     """ Returns a  metric list from the AWS CloudWatch service, may return
     None if no metric exists
@@ -134,15 +160,20 @@ def __get_aws_metric(table_name, gsi_name, time_frame, metric_name):
         A list of time series data for the given metric, may be None if
         there was no data
     """
-    return cloudwatch_connection.get_metric_statistics(
-        period=time_frame,
-        start_time=datetime.utcnow()-timedelta(minutes=10, seconds=time_frame),
-        end_time=datetime.utcnow()-timedelta(minutes=10),
-        metric_name=metric_name,
-        namespace='AWS/DynamoDB',
-        statistics=['Sum'],
-        dimensions={
-            'TableName': table_name,
-            'GlobalSecondaryIndexName': gsi_name
-        },
-        unit='Count')
+    try:
+        start_time = datetime.utcnow()-timedelta(minutes=10, seconds=time_frame)
+        end_time = datetime.utcnow()-timedelta(minutes=10)
+        return cloudwatch_connection.get_metric_statistics(
+            period=time_frame,
+            start_time=start_time,
+            end_time=end_time,
+            metric_name=metric_name,
+            namespace='AWS/DynamoDB',
+            statistics=['Sum'],
+            dimensions={
+                'TableName': table_name,
+                'GlobalSecondaryIndexName': gsi_name
+            },
+            unit='Count')
+    except BotoServerError:
+        raise
